SigningInfo

Struct SigningInfo 

pub struct SigningInfo {
    pub argon: [u8; 32],
    pub oscsprng: [u8; 32],
    pub pk_hash: String,
    pub id: String,
}
SigningInfo

The SigningInfo is serialized to YAML and signed. It contains Argon2id RNG (with nonce), and OSCSPRNG for RNG. It also contains the public key hash with the RNG to thwart attacks on randomness while proving the public key in the signature. Finally, it contains the signature ID.

Fields

argon: [u8; 32]oscsprng: [u8; 32]pk_hash: Stringid: String

Implementations

Source

impl SigningInfo

pub fn yamalize(&self) -> String

Serialize to YAML

pub fn get_integrity_as_bytes( &self, hasher: RustySignatureHashingIntegrity, ) -> Vec<u8>

Integrity

Retrieves RustySignatureIntegrity of SigningInfo (as Bytes)

pub fn integrity(&self, hasher: RustySignatureHashingIntegrity) -> String

Integrity

Retrieves RustySignatureIntegrity of SigningInfo (as Hex)